@@ -309,7 +309,7 @@ void ConstructClassifiers(void)
       }
     }
 
-    UnitWeights = false;
+    UnitWeights = binfalse;
   }
 
   FreeUnlessNil(SaveCase);
@@ -356,17 +356,17 @@ void InitialiseWeights(void)
     /*  Make weights proportional to average error cost  */
 
     ForEach(i, 0, MaxCase) { Weight(Case[i]) = WeightMul[Class(Case[i])]; }
-    UnitWeights = false;
+    UnitWeights = binfalse;
   } else {
     ForEach(i, 0, MaxCase) { Weight(Case[i]) = 1.0; }
-    UnitWeights = true;
+    UnitWeights = bintrue;
   }
 
   /*  Adjust when using case weights  */
 
   if (CWtAtt) {
     ForEach(i, 0, MaxCase) { Weight(Case[i]) *= RelCWt(Case[i]); }
-    UnitWeights = false;
+    UnitWeights = binfalse;
   }
 }
 
@@ -487,8 +487,9 @@ void EvaluateSingle(int Flags)
     if (RULES) {
       PredClass = RuleClassify(Case[i], RuleSet[0]);
     } else {
-      Verbosity(1, PredClass = TreeClassify(Case[i], Raw[0]);
-                if (PredClass != RealClass) { RawErrs++; })
+      Verbosity(
+          1, PredClass = TreeClassify(Case[i], Raw[0]);
+          if (PredClass != RealClass) { RawErrs++; })
 
           PredClass = TreeClassify(Case[i], Pruned[0]);
     }
@@ -713,7 +714,9 @@ void RecordAttUsage(DataRec Case, int *Usage)
       Usage[Att]++;
 
       if (AttDef[Att]) {
-        ForEach(i, 1, AttDefUses[Att][0]) { Tested[AttDefUses[Att][i]] = true; }
+        ForEach(i, 1, AttDefUses[Att][0]) {
+          Tested[AttDefUses[Att][i]] = bintrue;
+        }
       }
     }
   }
