@@ -53,12 +53,12 @@ AttValue _UNK, /* quasi-constant for unknown value */
 #define FailSyn(Msg)                                                           \
   {                                                                            \
     DefSyntaxError(Msg);                                                       \
-    return false;                                                              \
+    return binfalse;                                                           \
   }
 #define FailSem(Msg)                                                           \
   {                                                                            \
     DefSemanticsError(Fi, Msg, OpCode);                                        \
-    return false;                                                              \
+    return binfalse;                                                           \
   }
 
 typedef union _xstack_elt {
@@ -96,7 +96,7 @@ void ImplicitAtt(FILE *Nf)
 
   ReadDefinition(Nf);
 
-  PreviousError = false;
+  PreviousError = binfalse;
   BN = 0;
 
   /*  Allocate initial stack and attribute definition  */
@@ -157,13 +157,13 @@ void ImplicitAtt(FILE *Nf)
 void ReadDefinition(FILE *f)
 /*   --------------  */
 {
-  Boolean LastWasPeriod = false;
+  Boolean LastWasPeriod = binfalse;
   char c;
 
   Buff = Alloc(BuffSize = 50, char);
   BN = 0;
 
-  while (true) {
+  while (bintrue) {
     c = InChar(f);
 
     if (c == '|')
@@ -243,7 +243,7 @@ Boolean Expression(void)
     DumpOp(OP_OR, Fi);
   }
 
-  return true;
+  return bintrue;
 }
 
 Boolean Conjunct(void)
@@ -263,7 +263,7 @@ Boolean Conjunct(void)
     DumpOp(OP_AND, Fi);
   }
 
-  return true;
+  return bintrue;
 }
 
 String RelOps[] = {">=", "<=", "!=", "<>", ">", "<", "=", (String)0};
@@ -282,22 +282,17 @@ Boolean SExpression(void)
     if (!AExpression())
       FailSyn("expression");
 
-    DumpOp((o == 0
-                ? OP_GE
-                : o == 1 ? OP_LE
-                         : o == 4 ? OP_GT
-                                  : o == 5 ? OP_LT
-                                           : o == 2 || o == 3
-                                                 ? (TStack[TSN - 1].Type == 'S'
-                                                        ? OP_SNE
-                                                        : OP_NE)
-                                                 : (TStack[TSN - 1].Type == 'S'
-                                                        ? OP_SEQ
-                                                        : OP_EQ)),
+    DumpOp((o == 0   ? OP_GE
+            : o == 1 ? OP_LE
+            : o == 4 ? OP_GT
+            : o == 5 ? OP_LT
+            : o == 2 || o == 3
+                ? (TStack[TSN - 1].Type == 'S' ? OP_SNE : OP_NE)
+                : (TStack[TSN - 1].Type == 'S' ? OP_SEQ : OP_EQ)),
            Fi);
   }
 
-  return true;
+  return bintrue;
 }
 
 String AddOps[] = {"+", "-", (String)0};
@@ -329,7 +324,7 @@ Boolean AExpression(void)
     DumpOp((char)(OP_PLUS + o), Fi);
   }
 
-  return true;
+  return bintrue;
 }
 
 String MultOps[] = {"*", "/", "%", (String)0};
@@ -351,7 +346,7 @@ Boolean Term(void)
     DumpOp((char)(OP_MULT + o), Fi);
   }
 
-  return true;
+  return bintrue;
 }
 
 Boolean Factor(void)
@@ -371,14 +366,14 @@ Boolean Factor(void)
     DumpOp(OP_POW, Fi);
   }
 
-  return true;
+  return bintrue;
 }
 
 Boolean Primary(void)
 /*      -------  */
 {
   if (Atom()) {
-    return true;
+    return bintrue;
   } else if (Find("(")) {
     BN++;
     if (!Expression())
@@ -386,7 +381,7 @@ Boolean Primary(void)
     if (!Find(")"))
       FailSyn("')'");
     BN++;
-    return true;
+    return bintrue;
   } else {
     FailSyn("attribute, value, or '('");
   }
@@ -494,10 +489,10 @@ Boolean Atom(void)
       Dump(OP_STR, 0, strdup("N/A"), Fi);
     }
   } else {
-    return false;
+    return binfalse;
   }
 
-  return true;
+  return bintrue;
 }
 
 /*************************************************************************/
@@ -512,7 +507,7 @@ Boolean Find(String S)
   if (Buff[BN] == ' ')
     BN++;
 
-  return (!Buff[BN] ? false : !memcmp(Buff + BN, S, strlen(S)));
+  return (!Buff[BN] ? binfalse : !memcmp(Buff + BN, S, strlen(S)));
 }
 
 /*************************************************************************/
@@ -591,7 +586,7 @@ void DefSyntaxError(String Msg)
     }
 
     Error(BADDEF1, RestOfText, Msg);
-    PreviousError = true;
+    PreviousError = bintrue;
   }
 }
 
@@ -680,7 +675,7 @@ void DefSemanticsError(int Fi, String Msg, int OpCode)
 
     snprintf(XMsg, size_x, "%s with '%s'", Msg, Op);
     Error(BADDEF2, Exp, XMsg);
-    PreviousError = true;
+    PreviousError = bintrue;
   }
 }
 
@@ -814,7 +809,7 @@ Boolean UpdateTStack(char OpCode, ContValue F, String S, int Fi)
   TStack[TSN].Li = BN - 1;
   TSN++;
 
-  return true;
+  return bintrue;
 }
 
 /*************************************************************************/
@@ -926,16 +921,20 @@ AttValue EvaluateDef(Definition D, DataRec Case)
     case OP_SEQ:
       sv1 = XStack[XSN - 2].sval;
       sv2 = XStack[XSN - 1].sval;
-      XStack[XSN - 2].dval =
-          (!sv1 && !sv2 ? 2 : !sv1 || !sv2 ? 3 : !strcmp(sv1, sv2) ? 2 : 3);
+      XStack[XSN - 2].dval = (!sv1 && !sv2        ? 2
+                              : !sv1 || !sv2      ? 3
+                              : !strcmp(sv1, sv2) ? 2
+                                                  : 3);
       XSN--;
       break;
 
     case OP_SNE:
       sv1 = XStack[XSN - 2].sval;
       sv2 = XStack[XSN - 1].sval;
-      XStack[XSN - 2].dval =
-          (!sv1 && !sv2 ? 3 : !sv1 || !sv2 ? 2 : strcmp(sv1, sv2) ? 2 : 3);
+      XStack[XSN - 2].dval = (!sv1 && !sv2       ? 3
+                              : !sv1 || !sv2     ? 2
+                              : strcmp(sv1, sv2) ? 2
+                                                 : 3);
       XSN--;
       break;
 
